@@ -22,6 +22,15 @@
 #include <config.h>
 #endif
 
+#include <iostream>
+#include <algorithm>
+#include <string>
+
+#include <stdarg.h>
+#include <stdio.h>
+
+using namespace std; 
+
 #include "httphandler.h"
 
 
@@ -29,15 +38,31 @@ class ConnectionToBrowser : public HTTPHandler  {
 
 private:
 
-string host;
+string Request;
+
+string Host;
+
+int Port;
+
+
+string RequestType;
+
+bool AnalyseHeaderLine( string *RequestT );
+
+bool GetHostAndPortOfRequest(string *RequestT);
+
+bool GetHostAndPortOfHostLine( string *HostLineT );
 
 public:
 
-string Request;
-
 string PrepareHeaderForServer();
 
-bool GetHostAndPort( string *HostT, int *PortT );
+const char *GetHost();
+
+const char *GetCompleteRequest();
+
+int GetPort();
+
       
 	ConnectionToBrowser();
 	~ConnectionToBrowser();
