@@ -18,26 +18,23 @@
 #ifndef GENERICSCANNER_H
 #define GENERICSCANNER_H
 
-#include <pthread.h>
+#include <sys/types.h>
 
 #include <iostream>
+#include <string>
 
 using namespace std;
 
 
 class GenericScanner {
 
-private:
 
 protected:
 
-pthread_t ScannerThread;
-
-static pthread_mutex_t scan_mutex;
-
 string ScannerAnswer;
 
-string ErrorAnswer;
+pid_t ScannerPid;
+
 
 public:
 
@@ -45,12 +42,8 @@ void WriteScannerAnswer ();
 
 string ReadScannerAnswer ();
 
-string ReadErrorAnswer ();
-
 bool PrepareScanning ( void *GenericScannerT );
 
-static void *CallScanner ( void *prt );
-
 
 virtual bool InitDatabase() = 0;
 
@@ -60,7 +53,7 @@ virtual int Scanning () = 0;
 
 virtual bool InitSelfEngine() = 0;
 
-virtual bool ScanningComplete() = 0;
+virtual int ScanningComplete() = 0;
 
 virtual bool SetFileSize( unsigned long ContentLengthT ) = 0;
 
