@@ -15,13 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include "logfile.h"
 #include "default.h"
+#include "helper.h"
 #include "sockethandler.h"
 #include "genericscanner.h"
 #include "clamlibscanner.h"
@@ -31,23 +31,6 @@
 //#include <sys/types.h>
 //#include <unistd.h>
 
-
-int MakeDeamon()
-{
- pid_t deamon;
- if (( deamon = fork() ) < 0)
- { return (-1); //Parent error
- } else if ( deamon != 0) {
-  exit (0); //Parent exit
- }
-
- //Child
- setsid();
- chdir("/tmp/");
- umask(0);
- return (0);
-   
-}
                          
 int main(int argc, char *argv[])
 {
@@ -58,16 +41,43 @@ ProxyHandler Proxy;
 GenericScanner *VirusScanner = new (ClamLibScanner);
 
 
+if ( ChangeUserAndGroup( ) == false)
+  exit (-1);
+
+
+
 if (LogFile::InitLogFiles( ACCESSLOG, ERRORLOG ) == false){
   cout << "Could not create logfiles" << endl;
   exit (-1);
   }
   
+#ifdef  DISPLAYINITIALMESSAGES  
 cout << "Starting Havp Version:" << VERSION << endl;
+#endif
+
+
 LogFile::ErrorMessage("Starting Havp Version: %s\n", VERSION);
+#ifdef USER
+LogFile::ErrorMessage ("Change to User %s\n", USER);
+#endif
+#ifdef GROUP
+LogFile::ErrorMessage ("Change to Group %s\n", GROUP);
+#endif
+
+#if defined (PARENTPROXY) && defined (PARENTPORT)
+  LogFile::ErrorMessage("Use parent proxy: %s %d\n", PARENTPROXY, PARENTPORT );
+#endif
+
+#ifdef TRANSPARENT
+  LogFile::ErrorMessage("Use transparent proxy mode\n");
+#endif
+
+if( HardLockTest ( )!= 1) {
+  exit (-1);
+  }
 
 
-if( ProxyServer.CreateServer( PORT ) == false) {
+if( ProxyServer.CreateServer( PORT, BIND_ADDRESS ) == false) {
   cout << "Could not create Server" << endl;
   LogFile::ErrorMessage("Could not create Server\n");
   exit (-1);
@@ -80,7 +90,7 @@ if ( VirusScanner->InitDatabase( ) == false ) {
   exit (-1);
   }
 
-#ifdef DEAMON
+#ifdef DAEMON
 MakeDeamon();
 #endif
   
