@@ -22,6 +22,7 @@ bool HTTPHandler::ReadHeader( string *headerT )
 {
 
 string::size_type position;
+bool WrongHeader=false;
 int poscount = 0;
 ssize_t read;
 string tempheader="";
@@ -31,8 +32,16 @@ string tempheader="";
 if ( ( read = SocketHandler::Recv( &tempheader, false ) ) <= 0 ) {
    return false; }
 
+//Maybe we should also look for \n\n (19.3 RFC 1945 - Tolerant Applications)
 while ( (position = tempheader.find ("\r\n\r\n")) == string::npos )
 {
+
+ if ( (position = tempheader.find ("\n\n")) != string::npos )
+ {
+  WrongHeader=true;
+  break;
+ }
+  
  //Header not yet found
  //Read and delete part of header containing no \r\n\r\n
  SocketHandler::RecvLength(headerT, read );
@@ -47,27 +56,45 @@ while ( (position = tempheader.find ("\r\n\r\n")) == string::npos )
   return false; }
 }
 
+//cout << tempheader << endl;
 //Read last part of header
 if ( SocketHandler::RecvLength(headerT, position-poscount+2 ) == false ) {
   return false; }
 
-//Read last \r\n
-if ( SocketHandler::RecvLength(&tempheader, 2 ) == false ){
-  return false; }
-
+if ( WrongHeader == false )
+  {
+  //Read last \r\n
+  if ( SocketHandler::RecvLength(&tempheader, 2 ) == false ){
+   return false; }
+}
 return true;
 }
 
 
 //Split header to tokens
-bool HTTPHandler::TokenizeHeader(string *linesT, const char *delimitersT )
+bool HTTPHandler::AnalyseHeader(string *linesT, const char *delimitersT )
  {
 
+ string tempToken;
+   
  //delete tokens
  tokens.clear();
 
+ //Clear Content Length
+ ContentLength=0;
+ 
   string::size_type lastposition = 0;
   string::size_type length = linesT->length();
+
+  // Do "Tolerant Applications" - RFC 1945 - Hypertext Transfer Protocol -- HTTP/1.0
+  while ( (lastposition = linesT->find ("\r",lastposition)) != string::npos )
+  {  
+   linesT->replace( lastposition, 1, "" );
+  }
+
+  lastposition = 0;
+  length = linesT->length();
+          
   string::size_type position = linesT->find (delimitersT, 0);
 
   if ( position == string::npos )
@@ -77,9 +104,28 @@ bool HTTPHandler::TokenizeHeader(string *linesT, const char *delimitersT )
   
     while (position != string::npos && lastposition != length)
     {
-        tokens.push_back(linesT->substr(lastposition, position - lastposition + 2 ));
+        tempToken = linesT->substr(lastposition, position - lastposition );
 
-        lastposition = position + 2;
+        if ( (lastposition = tempToken.find_last_not_of("\t ")) != string::npos )
+        {
+        tempToken = tempToken.substr(0,lastposition+1);
+
+        if( (lastposition = tempToken.find("Content-Length: ",0) ) != string::npos)
+         {
+          lastposition = lastposition + 16;
+          string Length = tempToken.substr(lastposition, tempToken.length() );
+          if (sscanf( Length.c_str(), "%lu",  &ContentLength) != 1){
+          ContentLength=0;
+          }
+         }
+
+
+        AnalyseHeaderLine( &tempToken );
+
+        tokens.push_back(  tempToken+"\r\n" );
+        }
+        
+        lastposition = position + 1;
 
         position = linesT->find( delimitersT, lastposition);
     }
@@ -89,24 +135,10 @@ bool HTTPHandler::TokenizeHeader(string *linesT, const char *delimitersT )
 
 
 //Get Content Length
-unsigned long HTTPHandler::GetContentLength(string* HeaderT)
+unsigned long HTTPHandler::GetContentLength( )
 {
-string::size_type begin;
 
-    if( (begin = HeaderT->find("Content-Length: ",0) ) != string::npos)
-    {
-      begin = begin + 16;
-       string::size_type end = HeaderT->find("\r\n", begin);
-       string::size_type length = end - begin;
-       string Length = HeaderT->substr(begin, length );
-
-       //danger - ask for error
-       return atol( (char*)Length.c_str() );
-
-
-    } else {
-    return 0;
-    }
+ return ContentLength;
 
 }
 
