@@ -24,6 +24,7 @@
 #include "logfile.h"
 
 #include <iostream>
+#include <string>
 
 using namespace std;
 
@@ -34,8 +35,8 @@ private:
 
 bool HeaderSend;
 
-string Host;
-int Port;
+//string Host;
+//int Port;
 
 ConnectionToBrowser ToBrowser;
 ConnectionToServer ToServer;
