@@ -15,18 +15,20 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "sockethandler.h"
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <arpa/inet.h>
 #include <unistd.h>
+#include <fcntl.h>
+#include "sockethandler.h"
 
 //Create Server Socket
-bool SocketHandler::CreateServer( int portT )
+bool SocketHandler::CreateServer( int portT, in_addr_t bind_addrT )
 {
   int i = 1;
 
   s_addr.sin_family = AF_INET;
-  s_addr.sin_addr.s_addr = INADDR_ANY;
+  s_addr.sin_addr.s_addr = bind_addrT;
   s_addr.sin_port = htons ( portT );
 
   sock_fd = socket ( AF_INET, SOCK_STREAM, 0 );
@@ -48,6 +50,12 @@ bool SocketHandler::CreateServer( int portT )
   return true;
 }
 
+//Create Server Socket, convert ASCII address representation into binary one
+bool SocketHandler::CreateServer( int portT, const char *bind_addrT )
+{
+  return CreateServer( portT, bind_addrT == NULL ? INADDR_ANY : inet_addr( bind_addrT ) );
+}
+
 //Accept Client
 bool SocketHandler::AcceptClient ( SocketHandler *accept_socketT )
 {
@@ -178,6 +186,49 @@ bool SocketHandler::SetDomainAndPort(const char *domainT, int portT)
     }
 }
 
+bool SocketHandler::CheckForData( )
+{
+ fd_set checkfd;
+ struct timeval Timeout;
+ Timeout.tv_sec = 0;
+ Timeout.tv_usec = 0;
+ 
+  //Enable nonblocking sockets
+  fcntl(sock_fd, F_SETFL, O_NONBLOCK);
+ 
+  FD_ZERO(&checkfd);
+  FD_SET(sock_fd,&checkfd);
+
+  select( sock_fd+1 ,&checkfd, NULL, NULL, &Timeout);
+  
+  if (select( sock_fd+1 ,&checkfd, NULL, NULL, &Timeout) == 0){
+     //Disable nonblocking sockets
+     fcntl(sock_fd, F_SETFL, ~O_NONBLOCK);
+    return false;
+  }
+
+  //Disable nonblocking sockets
+  fcntl(sock_fd, F_SETFL, ~O_NONBLOCK);
+        
+return true;
+}
+
+
+bool SocketHandler::IsConnectionDropped()
+{
+char buffer[1];
+
+if( CheckForData() == true)
+{
+ if ( ::recv ( sock_fd, buffer, 1, MSG_PEEK ) == 0)
+ {
+  return true;
+ } 
+}
+    
+return false;
+}
+
 
 int SocketHandler::Close()
 {
